Fizzle_Inspect = Fizzle:NewModule("Inspect")
local _G = getfenv(0)
local gratuity = AceLibrary("Gratuity-2.0")
local deformat = AceLibrary("Deformat-2.0")

function Fizzle_Inspect:OnInitialize()
	self.db = Fizzle:AcquireDBNamespace("Inspect")
	self.slots = self.slots or {
		{slot = "Head"},
		{slot = "Shoulder"},
		{slot = "Chest"},
		{slot = "Waist"},
		{slot = "Legs"},
		{slot = "Feet"},
		{slot = "Wrist"},
		{slot = "Hands"},
		{slot = "MainHand"},
		{slot = "SecondaryHand"},
		{slot = "Ranged"},
		{slot = "Ammo"},
		{slot = "Neck"},
		{slot = "Back"},
		{slot = "Finger0"},
		{slot = "Finger1"},
		{slot = "Trinket0"},
		{slot = "Trinket1"},
		{slot = "Relic"}
	}
end

function Fizzle_Inspect:OnEnable()
	self:RegisterEvent("ADDON_LOADED")
end

function Fizzle_Inspect:CreateBorders()
	for _, item in pairs(self.slots) do
		-- Create borders
		Fizzle:CreateBorder("Inspect", item.slot, "Fizzspect", false)
	end
	self.booted = true
end

function Fizzle_Inspect:UpdateBorders()
	if not InspectFrame:IsVisible() then return end
	for _, item in pairs(self.slots) do
		ChatFrame1:AddMessage("A: Processing: "..item.slot)
		local id
		if _G["Character".. item.slot .."Slot"] then
			id = _G["Character".. item.slot .."Slot"]:GetID()
		end
		if id then
ChatFrame1:AddMessage("B: Found ID for: "..item.slot)
		--local hasItem, _, _ = gratuity:SetInventoryItem("target", id)
		local link = GetInventoryItemLink("target", id)
		local border = _G[item.slot .."FizzspectB"]
		if link then
ChatFrame1:AddMessage("C: Found link for: "..item.slot)
			--if not link then
			--	border:Hide()
			--	return
			--end
			local _, itemID, _, _, _, _, _, _, _ = deformat(link, "%s|Hitem:%d:%d:%d:%d:%d:%d:%d:%d|h[%s]|h%s")
			local _, _, quality, _, _, _, _, _, _, _ = GetItemInfo(itemID)
			
			if quality then
				local r, g, b, _ = GetItemQualityColor(quality)
				border:SetVertexColor(r, g, b)
				border:Show()
			else
				border:Hide()
			end
		else
			ChatFrame1:AddMessage("Hiding: "..item.slot)
			border:Hide()
		end
	else
		ChatFrame1:AddMessage("No ID for: "..item.slot)
	end
	end
end

function Fizzle_Inspect:ADDON_LOADED()
	-- If the Blizzard InspectUI is loading, fire up the addon!
	if arg1 == "Blizzard_InspectUI" then
		self:SecureHook("InspectFrame_OnShow")
		self:SecureHook("InspectFrame_OnHide")
		self:UnregisterEvent("ADDON_LOADED")
		self:InspectFrame_OnShow()
	end
end

function Fizzle_Inspect:InspectFrame_OnShow()
	-- Hook the unit changed thing, so that the borders update if equipment is changed
	if not self:IsEventRegistered("UNIT_INVENTORY_CHANGED") then
		self:RegisterEvent("UNIT_INVENTORY_CHANGED", "UpdateBorders")
	end

	-- Create the borders if we're just loading.
	if not self.booted then
		self:CreateBorders()
	end
	
	-- Update the borders
	self:UpdateBorders()
end

function Fizzle_Inspect:InspectFrame_OnHide()
	-- Unhook the event when the frame is closed.
	if self:IsEventRegistered("UNIT_INVENTORY_CHANGED") then
		self:UnregisterEvent("UNIT_INVENTORY_CHANGED")
	end
end
